@@ -35,6 +35,8 @@ class KPageViewPrivate;
 class QAbstractItemModel;
 
 /**
+ * @class KPageView kpageview.h KPageView
+ *
  * @short A base class which can handle multiple pages.
  *
  * This class provides a widget base class which handles multiple
@@ -42,7 +44,7 @@ class QAbstractItemModel;
  * different ways.
  *
  * Currently, @p Auto, @p Plain, @p List, @p Tree and @p Tabbed face
- * types are available. @see KPageWidget
+ * types are available (cmp. KPageWidget).
  *
  * <b>Example:</b>\n
  *
@@ -67,25 +69,31 @@ public:
     /**
      * This enum is used to decide which type of navigation view
      * shall be used in the page view.
-     *
-     * @li Auto   - Depending on the number of pages in the model,
-     *              the Plain (one page), the List (several pages)
-     *              or the Tree face (nested pages) will be used.
-     *              This is the default face type.
-     * @li Plain  - No navigation view will be visible and only the
-     *              first page of the model will be shown.
-     *
-     * @li List   - An icon list is used as navigation view.
-     *
-     * @li Tree   - A tree list is used as navigation view.
-     *
-     * @li Tabbed - A tab widget is used as navigation view.
      */
     enum FaceType {
+        /**
+         * Depending on the number of pages in the model,
+         * the @c Plain (one page), the @c List (several pages)
+         * or the @c Tree face (nested pages) will be used.
+         * This is the default face type.
+         */
         Auto,
+        /**
+         * No navigation view will be visible and only the
+         * first page of the model will be shown.
+         */
         Plain,
+        /**
+         * An icon list is used as navigation view
+         */
         List,
+        /**
+         * A tree list is used as navigation view
+         */
         Tree,
+        /**
+         * A tab widget is used as navigation view
+         */
         Tabbed
     };
     Q_ENUM(FaceType)
@@ -93,7 +101,7 @@ public:
     /**
      * Creates a page view with given parent.
      */
-    explicit KPageView(QWidget *parent = 0);
+    explicit KPageView(QWidget *parent = nullptr);
 
     /**
      * Destroys the page view.
@@ -124,7 +132,7 @@ public:
 
     /**
      * Sets the page with @param index to be the current page and emits
-     * the @see currentPageChanged signal.
+     * the signal currentPageChanged.
      */
     void setCurrentPage(const QModelIndex &index);
 
